==> haskell-binary-conduit-1.3.1-581-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-HFXEMb0wG54FeW1bU1jiDs
key:                  binary-conduit-1.3.1-HFXEMb0wG54FeW1bU1jiDs
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  2fea285766c63b5e1e019aa0f60047ad
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-conduit-1.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-HFXEMb0wG54FeW1bU1jiDs
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh exceptions-0.10.7
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3.1-583-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-D2HERwCAm7CAQcpQOsz2qy
key:                  binary-conduit-1.3.1-D2HERwCAm7CAQcpQOsz2qy
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  3802a6e096baffeed559f7a815a61944
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-conduit-1.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-D2HERwCAm7CAQcpQOsz2qy
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy exceptions-0.10.7
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
